<?php
/**
 * 使用数据库保存配置的类的文件
 * 
 * @author dongbeta <xii@dongbeta.com>
 * @copyright Copyright @ 2010 Xii Project
 * @link http://xii.googlecode.com
 * @license http://www.opensource.org/licenses/bsd-license.php
 * @version $Id$
 */
Yii::import('application.components.config.XConfig');
Yii::import('application.components.config.XDbConfigRecord');
/**
 * 使用数据库存储和读取配置信息。
 * 
 * @example
 * 
 * 新增或者更新配置：
 * Yii::app()->config->set('name', 'value');
 * 读取配置：
 * Yii::app()->config->get('name', 'default');
 * 
 * @author dongbeta <xii@dongbeta.com>
 * @version $Id$
 * @package package xii.components.config
 */
class XDbConfig extends XConfig
{

	/**
	 * @var string 数据库表名称
	 */
	public $table = '{{config}}';

	/**
	 * 更新数据库记录
	 * @param string $name 配置项名称
	 * @param mixed $value 配置项的值
	 * @return boolean 是否更新成功
	 */
	protected function update($name, $value)
	{
		$config = XDbConfigRecord::model()->findByAttributes(array('name'=>$name));
		if ($config instanceof XDbConfigRecord) {
			$config->value = $value;
			return $config->save();
		}
		return false;	
	}
	
	/**
	 * 增加数据库记录
	 * @param string $name 配置项名称
	 * @param mixed $value 配置项的值
	 * @return boolean 是否添加成功
	 */
	protected function add($name, $value)
	{
		$config = new XDbConfigRecord();
		$config->setAttributes(array('name'=>$name, 'value'=>$value));
		return $config->save();
	}

	/**
	 * 从数据库中读取
	 * @param string $name 配置项名称
	 * @return boolean 是否读取成功
	 */
	protected function find($name)
	{
		$model = XDbConfigRecord::model()->findByPk($name);
		if ($model instanceof XDbConfigRecord) {
		    $this->setValue($name, $model->value);
		    return $model;
		}else 
		    return false;
	}

	/**
	 * 判断某项配置是否存在
	 * @param string $name 配置项名称
	 * @return boolean 是否存在
	 */
	protected function exist($name)
	{
		return XDbConfigRecord::model()->exists('`name`=:name', array(':name'=>$name));
	}
}