<?php
/**
 * 数据库存储配置，数据库模型类文件
 * 
 * @author dongbeta <xii@dongbeta.com>
 * @link http://xii.googlecode.com
 * @copyright Copyright @ 2010 Xii Project
 * @license http://www.opensource.org/licenses/bsd-license.php
 */

/**
 * 数据库模型类
 * @author dongbeta <xii@dongbeta.com>
 * @version $Id$
 * @package package xii.components.config
 */
class XDbConfigRecord extends CActiveRecord
{
	/**
	 * 返回XDbConfigRecord类的静态模型
	 * @return XDbConfigRecord 模型实例
	 */
	public static function model($model = __CLASS__)
	{
		return parent::model($model);
	}

	/**
	 * 返回数据库表名，从XDbConfig类中获取
	 * @return string 表名
	 */
	public function tableName()
	{
		return Yii::app()->config->table;
	}
	
	/**
	 * 返回主键名
	 * @return string 主键名
	 */
	public function primaryKey()
	{
		return 'name';
	}
	
	/**
	 * 返回属性的验证规则，用于函数{@link validate()}
	 * @return array 验证规则数组
	 */
	public function rules()
	{
		return array(
			array('name', 'match', 'pattern'=>'/^[a-zA-Z0\._-]+$/'),
			array('name, value', 'safe'),
		);
	}
	
	/**
	 * 保存之前将value的值序列化
	 * @return boolean
	 */
	public function beforeSave()
	{
		if (parent::beforeSave()) {
			$this->value = serialize($this->value);
			return true;
		}
		return false;
	}
	
	/**
	 * 读取记录之后，恢复里面存储的值为原始格式
	 */
	public function afterFind()
	{
		$this->value = unserialize($this->value);
	}
}